@@ -336,7 +336,7 @@ class bilde_svg_renderer extends bilde_renderer
 
 		$this->svg->appendChild($rect);
 	}
-	public function draw_arc($center_x, $center_y, $radius, $offset_percent, $percent, $body_color, $border_color = null, $border_width = 1, $title = null)
+	public function draw_arc($center_x, $center_y, $radius, $offset_percent, $percent, $body_color, $border_color = null, $border_width = 1, $title = null, $dash = false)
 	{
 		$deg = ($percent * 360);
 		$offset_deg = ($offset_percent * 360);
@@ -354,6 +354,11 @@ class bilde_svg_renderer extends bilde_renderer
 		$path->setAttribute('stroke-width', $border_width);
 		$path->setAttribute('stroke-linejoin', 'round');
 
+		if($dash)
+		{
+			$path->setAttribute('stroke-dasharray', '10,20');
+		}
+
 		if($title != null)
 		{
 			$path->setAttribute('xlink:title', $title);
@@ -361,7 +366,7 @@ class bilde_svg_renderer extends bilde_renderer
 
 		$this->svg->appendChild($path);
 	}
-	public function draw_polygon($points, $body_color, $border_color = null, $border_width = 0)
+	public function draw_polygon($points, $body_color, $border_color = null, $border_width = 0, $title = null)
 	{
 		$point_pairs = array();
 		$this_pair = array();
@@ -398,6 +403,36 @@ class bilde_svg_renderer extends bilde_renderer
 			$polygon->setAttribute('points', implode(' ', $point_pairs));
 		}
 
+		if($title != null)
+		{
+			$polygon->setAttribute('xlink:title', $title);
+			/*static $id_counter = 0;
+			$id_counter++;
+			$polygon->setAttribute('id', 'phover' . $id_counter);
+
+			$text = $this->image->createElement('text');
+			$text->setAttribute('id', 'po' . $id_counter);
+			$text->setAttribute('fill', $border_color);
+			//$text->setAttribute('font-size', '30');
+			$text->setAttribute('visibility', 'hidden');
+			$xy = explode(',', $point_pairs[0]);
+			$text->setAttribute('x', array_shift($xy));
+			$text->setAttribute('y', array_shift($xy));
+
+			$string = $this->image->createTextNode($title);
+			$text->appendChild($string);
+
+			$set = $this->image->createElement('set');
+			$set->setAttribute('attributeName', 'visibility');
+			$set->setAttribute('from', 'hidden');
+			$set->setAttribute('to', 'visible');
+			$set->setAttribute('begin', 'phover' . $id_counter . '.mouseover');
+			$set->setAttribute('end', 'phover' . $id_counter . '.mouseout');
+			$text->appendChild($set);
+			$this->svg->appendChild($polygon);
+			$this->svg->appendChild($text);*/
+		}
+
 		$this->svg->appendChild($polygon);
 	}
 	public function draw_ellipse($center_x, $center_y, $width, $height, $body_color, $border_color = null, $border_width = 0, $default_hide = false, $title = null)
