@@ -28,16 +28,16 @@ class phodevi_gpu extends phodevi_device_interface
 		switch($identifier)
 		{
 			case 'identifier':
-				$property = new phodevi_device_property('gpu_string', phodevi::smart_caching);
+				$property = new phodevi_device_property('gpu_string', phodevi::std_caching);
 				break;
 			case 'model':
 				$property = new phodevi_device_property('gpu_model', phodevi::smart_caching);
 				break;
 			case 'frequency':
-				$property = new phodevi_device_property('gpu_frequency_string', phodevi::smart_caching);
+				$property = new phodevi_device_property('gpu_frequency_string', phodevi::std_caching);
 				break;
 			case 'stock-frequency':
-				$property = new phodevi_device_property('gpu_stock_frequency', phodevi::smart_caching);
+				$property = new phodevi_device_property('gpu_stock_frequency', phodevi::std_caching);
 				break;
 			case 'memory-capacity':
 				$property = new phodevi_device_property('gpu_memory_size', phodevi::smart_caching);
@@ -49,7 +49,7 @@ class phodevi_gpu extends phodevi_device_interface
 				$property = new phodevi_device_property('gpu_af_level', phodevi::no_caching);
 				break;
 			case 'compute-cores':
-				$property = new phodevi_device_property('gpu_compute_cores', phodevi::std_caching);
+				$property = new phodevi_device_property('gpu_compute_cores', phodevi::smart_caching);
 				break;
 			case 'available-modes':
 				$property = new phodevi_device_property('gpu_available_modes', phodevi::smart_caching);
@@ -435,7 +435,12 @@ class phodevi_gpu extends phodevi_device_interface
 
 					if(is_numeric($res[0]) && is_numeric($res[1]))
 					{
-						array_push($available_modes, array($res[0], $res[1]));
+						$m = array($res[0], $res[1]);
+						if(!in_array($m, $available_modes))
+						{
+							// Don't repeat modes
+							array_push($available_modes, $m);
+						}
 					}
 				}
 			}
@@ -531,14 +536,15 @@ class phodevi_gpu extends phodevi_device_interface
 	public static function gpu_memory_size()
 	{
 		// Graphics memory capacity
-		$video_ram = 64; // Assume 64MB of video RAM at least
+		$video_ram = -1;
 
-		if(($vram = getenv('VIDEO_MEMORY')) != false && is_numeric($vram) && $vram > $video_ram)
+		if(($vram = getenv('VIDEO_MEMORY')) != false && is_numeric($vram))
 		{
 			$video_ram = $vram;
 		}
 		else if(is_file('/sys/kernel/debug/dri/0/memory'))
 		{
+			// This is how some of the Nouveau DRM VRAM is reported
 			$memory = file_get_contents('/sys/kernel/debug/dri/0/memory');
 
 			if(($x = strpos($memory, 'VRAM total: ')) !== false)
@@ -556,53 +562,85 @@ class phodevi_gpu extends phodevi_device_interface
 				}
 			}
 		}
-		else
+		else if(phodevi::is_nvidia_graphics() && ($NVIDIA = phodevi_parser::read_nvidia_extension('VideoRam')) > 0) // NVIDIA blob
 		{
-			if(phodevi::is_nvidia_graphics() && ($NVIDIA = phodevi_parser::read_nvidia_extension('VideoRam')) > 0) // NVIDIA blob
-			{
-				$video_ram = $NVIDIA / 1024;
-			}
-			else if(phodevi::is_macosx())
-			{
-				$info = phodevi_osx_parser::read_osx_system_profiler('SPDisplaysDataType', 'VRAM');
-				$info = explode(' ', $info);
-				$video_ram = $info[0];
-			
-				if($info[1] == 'GB')
-				{
-					$video_ram *= 1024;
-				}
-			}
-			else if(is_file('/var/log/Xorg.0.log'))
-			{
-				// Attempt Video RAM detection using X log
-				// fglrx driver reports video memory to: (--) fglrx(0): VideoRAM: XXXXXX kByte, Type: DDR
-				// xf86-video-ati, xf86-video-intel, and xf86-video-radeonhd also report their memory information in a similar format
+			$video_ram = $NVIDIA / 1024;
+		}
+		else if(phodevi::is_macosx())
+		{
+			$info = phodevi_osx_parser::read_osx_system_profiler('SPDisplaysDataType', 'VRAM');
+			$info = explode(' ', $info);
+			$video_ram = $info[0];
 
-				$info = shell_exec('cat /var/log/Xorg.0.log | grep -i VideoRAM');
+			if($info[1] == 'GB')
+			{
+				$video_ram *= 1024;
+			}
+		}
 
-				if(empty($info))
+		if($video_ram == -1 && is_file('/var/log/Xorg.0.log'))
+		{
+			// Attempt Video RAM detection using X log
+			// fglrx driver reports video memory to: (--) fglrx(0): VideoRAM: XXXXXX kByte, Type: DDR
+			// xf86-video-ati, xf86-video-intel, and xf86-video-radeonhd also report their memory information in a similar format
+
+			$info = shell_exec('cat /var/log/Xorg.0.log | grep -i VideoRAM');
+
+			if(empty($info))
+			{
+				$info = shell_exec('cat /var/log/Xorg.0.log | grep "Video RAM"');
+			}
+
+			if(($pos = stripos($info, 'RAM:') + 5) > 5 || ($pos = strpos($info, 'RAM=') + 4) > 4)
+			{
+				$info = substr($info, $pos);
+				$info = substr($info, 0, strpos($info, ' '));
+
+				if(!is_numeric($info) && ($cut = strpos($info, ',')))
 				{
-					$info = shell_exec('cat /var/log/Xorg.0.log | grep "Video RAM"');
+					$info = substr($info, 0, $cut);
 				}
 
-				if(($pos = stripos($info, 'RAM:') + 5) > 5 || ($pos = strpos($info, 'RAM=') + 4) > 4)
+				if($info > 65535)
 				{
-					$info = substr($info, $pos);
-					$info = substr($info, 0, strpos($info, ' '));
-
-					if(!is_numeric($info) && ($cut = strpos($info, ',')))
-					{
-						$info = substr($info, 0, $cut);
-					}
-
-					if($info > 65535)
-					{
-						$video_ram = intval($info) / 1024;
-					}
+					$video_ram = intval($info) / 1024;
 				}
 			}
 		}
+		if($video_ram == -1 && pts_client::executable_in_path('dmesg'))
+		{
+			// Fallback to try to find vRAM from dmesg
+			$info = shell_exec('dmesg 2> /dev/null');
+
+			if(($x = strpos($info, 'Detected VRAM RAM=')) !== false)
+			{
+				// Radeon DRM at least reports: [drm] Detected VRAM RAM=2048M, BAR=256M
+				$info = substr($info, $x + 18);
+				$info = substr($info, 0, strpos($info, 'M'));
+			}
+			else if(($x = strpos($info, 'M of VRAM')) !== false)
+			{
+				// Radeon DRM around Linux ~3.0 reports e.g.: [drm] radeon: 2048M of VRAM memory ready
+				$info = substr($info, 0, $x);
+				$info = substr($info, strrpos($info, ' ') + 1);
+			}
+			else if(($x = strpos($info, 'MiB VRAM')) !== false)
+			{
+				// Nouveau DRM around Linux ~3.0 reports e.g.: [drm] nouveau XXX: Detected 1024MiB VRAM
+				$info = substr($info, 0, $x);
+				$info = substr($info, strrpos($info, ' ') + 1);
+			}
+
+			if(is_numeric($info))
+			{
+				$video_ram = $info;
+			}
+		}
+
+		if($video_ram == -1 || !is_numeric($video_ram) || $video_ram < 64)
+		{
+			$video_ram = 64; // default to 64MB of video RAM as something sane...
+		}
 
 		return $video_ram;
 	}
@@ -647,7 +685,12 @@ class phodevi_gpu extends phodevi_device_interface
 		if(phodevi::is_nvidia_graphics() && phodevi::is_macosx() == false) // NVIDIA GPU
 		{
 			// GPUDefault3DClockFreqs is the default and does not show under/over-clocking
-			list($core_freq, $mem_freq) = pts_strings::comma_explode(phodevi_parser::read_nvidia_extension('GPU3DClockFreqs'));
+			$clock_freqs_3d = pts_strings::comma_explode(phodevi_parser::read_nvidia_extension('GPU3DClockFreqs'));
+
+			if(is_array($clock_freqs_3d) && isset($clock_freqs_3d[1]))
+			{
+				list($core_freq, $mem_freq) = $clock_freqs_3d;
+			}
 		}
 		else if(phodevi::is_ati_graphics() && phodevi::is_linux()) // ATI GPU
 		{
@@ -730,15 +773,33 @@ class phodevi_gpu extends phodevi_device_interface
 					}				
 					break;
 				case 'intel':
-					if(is_file('/sys/kernel/debug/dri/0/i915_cur_delayinfo'))
+					// try to read the maximum dynamic frequency
+					if(is_file('/sys/kernel/debug/dri/0/i915_max_freq'))
+					{
+						$i915_max_freq = pts_file_io::file_get_contents('/sys/kernel/debug/dri/0/i915_max_freq');
+						$freq_mhz = substr($i915_max_freq, strpos($i915_max_freq, ': ') + 2);
+
+						if(is_numeric($freq_mhz))
+						{
+							$core_freq = $freq_mhz;
+						}
+					}
+
+					// Fallback to base frequency
+					if($core_freq == 0 && is_file('/sys/kernel/debug/dri/0/i915_cur_delayinfo'))
 					{
 						$i915_cur_delayinfo = file_get_contents('/sys/kernel/debug/dri/0/i915_cur_delayinfo');
-						$freq = strpos($i915_cur_delayinfo, 'Nominal (RP1) frequency: ');
+						$freq = strpos($i915_cur_delayinfo, 'Max non-overclocked (RP0) frequency: ');
+
+						if($freq === false)
+						{
+							$freq = strpos($i915_cur_delayinfo, 'Nominal (RP1) frequency: ');
+						}
 
 						if($freq !== false)
 						{
-							$freq_mhz = substr($i915_cur_delayinfo, $freq + 25);
-							$freq_mhz = substr($freq_mhz, 0, strpos($freq_mhz, 'MHz'));
+							$freq_mhz = substr($i915_cur_delayinfo, strpos($i915_cur_delayinfo, ': ', $freq) + 2);
+							$freq_mhz = trim(substr($freq_mhz, 0, strpos($freq_mhz, 'MHz')));
 
 							if(is_numeric($freq_mhz))
 							{
@@ -891,7 +952,7 @@ class phodevi_gpu extends phodevi_device_interface
 	
 		if(empty($info) || strpos($info, 'Mesa ') !== false || strpos($info, 'Gallium ') !== false || $info == 'Software Rasterizer')
 		{
-			if(phodevi::is_linux() || phodevi::is_hurd())
+			if(phodevi::is_windows() == false)
 			{
 				$info_pci = phodevi_linux_parser::read_pci('VGA compatible controller', false);
 
