@@ -174,9 +174,10 @@ class phodevi_system extends phodevi_device_interface
 			if(pts_client::executable_in_path('mount'))
 			{
 				$mount = shell_exec('mount 2>&1');
-				
+
 				if(($start = strpos($mount, 'on / (')) != false)
 				{
+					// FreeBSD, DragonflyBSD mount formatting
 					/*
 					-bash-4.0$ mount
 					ROOT on / (hammer, local)
@@ -195,6 +196,13 @@ class phodevi_system extends phodevi_device_interface
 					$fs = substr($mount, $start + 6);
 					$fs = substr($fs, 0, strpos($fs, ','));
 				}
+				else if(($start = strpos($mount, 'on / type')) != false)
+				{
+					// OpenBSD 5.0 formatting is slightly different from above FreeBSD example
+					// TODO: improve this in case there are other partitions, etc
+					$fs = substr($mount, $start + 10);
+					$fs = substr($fs, 0, strpos($fs, ' '));
+				}
 			}
 		}
 		else if(phodevi::is_hurd())
@@ -334,10 +342,21 @@ class phodevi_system extends phodevi_device_interface
 		// Reports if system is running virtualized
 		$virtualized = null;
 		$gpu = phodevi::read_name('gpu');
+		$cpu = phodevi::read_property('cpu', 'model');
 
-		if(strpos(phodevi::read_property('cpu', 'model'), 'QEMU') !== false || (is_readable('/sys/class/dmi/id/bios_vendor') && pts_file_io::file_get_contents('/sys/class/dmi/id/bios_vendor') == 'QEMU'))
+		if(strpos($cpu, 'QEMU') !== false || (is_readable('/sys/class/dmi/id/bios_vendor') && pts_file_io::file_get_contents('/sys/class/dmi/id/bios_vendor') == 'QEMU'))
 		{
 			$virtualized = 'QEMU';
+
+			if(strpos($cpu, 'QEMU Virtual') !== false)
+			{
+				$qemu_version = substr($cpu, (strrpos($cpu, ' ') + 1));
+
+				if(pts_strings::string_only_contains($qemu_version, pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL))
+				{
+					$virtualized .= ' ' . $qemu_version;
+				}
+			}
 		}
 		else if(strpos($gpu, 'VMware') !== false || (is_readable('/sys/class/dmi/id/product_name') && stripos(pts_file_io::file_get_contents('/sys/class/dmi/id/product_name'), 'VMware') !== false))
 		{
@@ -346,6 +365,31 @@ class phodevi_system extends phodevi_device_interface
 		else if(strpos($gpu, 'VirtualBox') !== false || strpos(phodevi::read_name('motherboard'), 'VirtualBox') !== false)
 		{
 			$virtualized = 'VirtualBox';
+
+			if($vbox_manage = pts_client::executable_in_path('VBoxManage'))
+			{
+				$vbox_manage = trim(shell_exec($vbox_manage . ' --version 2> /dev/null'));
+
+				if(is_numeric(substr($vbox_manage, 0, 1)))
+				{
+					$virtualized .= ' ' . $vbox_manage;
+				}
+			}
+
+		}
+		else if(is_file('/sys/class/dmi/id/sys_vendor') && pts_file_io::file_get_contents('/sys/class/dmi/id/sys_vendor') == 'Xen')
+		{
+			$virtualized = pts_file_io::file_get_contents('/sys/class/dmi/id/product_name');
+
+			if(strpos($virtualized, 'Xen') === false)
+			{
+				$virtualized = 'Xen ' . $virtualized;
+			}
+
+			// version string
+			$virtualized .= ' ' . pts_file_io::file_get_contents('/sys/class/dmi/id/product_version');
+
+			// $virtualized should be then e.g. 'Xen HVM domU 4.1.1'
 		}
 
 		return $virtualized;
@@ -402,11 +446,68 @@ class phodevi_system extends phodevi_device_interface
 		if(pts_client::executable_in_path('clang'))
 		{
 			// Clang
-			$compiler_info = 'Clang ' . trim(shell_exec('clang -dumpversion 2>&1'));
-			$compilers['clang'] = trim($compiler_info);
+			$compiler_info = shell_exec('clang --version 2> /dev/null');
+			if(($cv_pos = stripos($compiler_info, 'clang version')) !== false)
+			{
+				// With Clang 3.0 and prior, the --version produces output where the first line is:
+				// e.g. clang version 3.0 (branches/release_30 142590)
+
+				$compiler_info = substr($compiler_info, ($cv_pos + 14));
+				$clang_version = substr($compiler_info, 0, strpos($compiler_info, ' '));
+
+				if(pts_strings::string_only_contains($clang_version, pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL))
+				{
+					// Also see if there is a Clang SVN tag to fetch
+					$compiler_info = substr($compiler_info, 0, strpos($compiler_info, PHP_EOL));
+					if(($cv_pos = strpos($compiler_info, ')')) !== false)
+					{
+						$compiler_info = substr($compiler_info, 0, $cv_pos);
+						$compiler_info = substr($compiler_info, (strrpos($compiler_info, ' ') + 1));
+
+						if(is_numeric($compiler_info))
+						{
+							// Right now Clang/LLVM uses SVN system and their revisions are only numeric
+							$clang_version .= ' (SVN ' . $compiler_info . ')';
+						}
+					}
+
+					$compiler_info = 'Clang ' . $clang_version;
+				}
+				else
+				{
+					$compiler_info = null;
+				}
+			}
+
+			// Clang
+			if(empty($compiler_info))
+			{
+				// At least with Clang ~3.0 the -dumpversion is reporting '4.2.1' ratherthan the useful information...
+				// This is likely just for GCC command compatibility, so only use this as a fallback
+				$compiler_info = 'Clang ' . trim(shell_exec('clang -dumpversion 2> /dev/null'));
+			}
+
+			$compilers['clang'] = $compiler_info;
 		}
 
-		if(pts_client::executable_in_path('llvmc'))
+		if(pts_client::executable_in_path('llvm-ld'))
+		{
+			// LLVM - Low Level Virtual Machine
+			// Reading the version from llvm-ld (the LLVM linker) should be safe as well for finding out version of LLVM in use
+			$info = trim(shell_exec('llvm-ld --version 2> /dev/null'));
+
+			if(($s = strpos($info, 'version')) != false)
+			{
+				$info = substr($info, 0, strpos($info, PHP_EOL, $s));
+				$info = substr($info, (strrpos($info, ' ') + 1));
+
+				if(pts_strings::string_only_contains($info, pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL))
+				{
+					$compilers['llvmc'] = 'LLVM ' . $info;
+				}
+			}
+		}
+		else if(pts_client::executable_in_path('llvmc'))
 		{
 			// LLVM - Low Level Virtual Machine (llvmc)
 			$info = trim(shell_exec('llvmc -version 2>&1'));
@@ -434,6 +535,12 @@ class phodevi_system extends phodevi_device_interface
 			}
 		}
 
+		if(pts_client::executable_in_path('icc'))
+		{
+			// Intel C++ Compiler
+			$compilers['icc'] = 'ICC';
+		}
+
 		// Try to make the compiler that's used by default to appear first
 		if(pts_client::read_env('CC') && isset($compilers[basename(pts_client::read_env('CC'))]))
 		{
@@ -560,7 +667,7 @@ class phodevi_system extends phodevi_device_interface
 
 					if(trim($file) != null)
 					{
-						$proposed_os = substr($file, 0, strpos($file, "\n"));
+						$proposed_os = substr($file, 0, strpos($file, PHP_EOL));
 
 						if(strpos($proposed_os, '=') == false)
 						{
@@ -592,6 +699,10 @@ class phodevi_system extends phodevi_device_interface
 				{
 					$os = trim(exec('ver'));
 				}
+				if(is_file('/etc/debian_version'))
+				{
+					$os = 'Debian ' . php_uname('s') . ' ' . ucwords(pts_file_io::file_get_contents('/etc/debian_version'));
+				}
 				else
 				{
 					$os = php_uname('s');
@@ -632,6 +743,10 @@ class phodevi_system extends phodevi_device_interface
 			{
 				$desktop_version = pts_strings::last_in_string(trim(shell_exec('gnome-about --version 2> /dev/null')));
 			}
+			else if(pts_client::executable_in_path('gnome-session'))
+			{
+				$desktop_version = pts_strings::last_in_string(trim(shell_exec('gnome-session --version 2> /dev/null')));
+			}
 		}
 		else if(pts_client::is_process_running('gnome-shell'))
 		{
@@ -643,20 +758,20 @@ class phodevi_system extends phodevi_device_interface
 				$desktop_version = pts_strings::last_in_string(trim(shell_exec('gnome-shell --version 2> /dev/null')));
 			}
 		}
-		else if(pts_client::is_process_running('unity-panel-service'))
+		else if(pts_client::is_process_running('unity-2d-panel'))
 		{
-			// Canonical / Ubuntu Unity Desktop
-			$desktop_environment = 'Unity';
+			// Canonical / Ubuntu Unity 2D Desktop
+			$desktop_environment = 'Unity 2D';
 
 			if(pts_client::executable_in_path('unity'))
 			{
 				$desktop_version = pts_strings::last_in_string(trim(shell_exec('unity --version 2> /dev/null')));
 			}
 		}
-		else if(pts_client::is_process_running('unity-2d-panel'))
+		else if(pts_client::is_process_running('unity-panel-service'))
 		{
-			// Canonical / Ubuntu Unity 2D Desktop
-			$desktop_environment = 'Unity 2D';
+			// Canonical / Ubuntu Unity Desktop
+			$desktop_environment = 'Unity';
 
 			if(pts_client::executable_in_path('unity'))
 			{
@@ -727,9 +842,8 @@ class phodevi_system extends phodevi_device_interface
 		if(!empty($desktop_environment))
 		{
 			$desktop = $desktop_environment;
-			$version_check = str_replace(array('.', 1, 2, 3, 4, 5, 6, 7, 8, 9, 0), null, $desktop_version);
 
-			if(!empty($desktop_version) && empty($version_check))
+			if(!empty($desktop_version) && pts_strings::string_only_contains($desktop_version, pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL))
 			{
 				$desktop .= ' ' . $desktop_version;
 			}
@@ -825,6 +939,15 @@ class phodevi_system extends phodevi_device_interface
 			{
 				switch($display_driver)
 				{
+					case 'amd':
+						// See if it's radeon driver
+						$driver_version = phodevi_parser::read_xorg_module_version('radeon_drv');
+
+						if($driver_version != false)
+						{
+							$display_driver = 'radeon';
+						}
+						break;
 					case 'radeon':
 						// RadeonHD driver also reports DRI driver as 'radeon', so try reading that instead
 						$driver_version = phodevi_parser::read_xorg_module_version('radeonhd_drv');
@@ -874,7 +997,7 @@ class phodevi_system extends phodevi_device_interface
 				{
 					$catalyst_version = phodevi_linux_parser::read_amd_pcsdb('AMDPCSROOT/SYSTEM/LDC,Catalyst_Version');
 
-					if($catalyst_version != null && $catalyst_version > 10.1 && $catalyst_version != 10.5)
+					if($catalyst_version != null && $catalyst_version > 10.1 && $catalyst_version != 10.5 && $catalyst_version != 11.8)
 					{
 						// This option was introduced around Catalyst 10.5 but seems to not be updated properly until Catalyst 10.11/10.12
 						$display_driver .= ' Catalyst ' . $catalyst_version . '';
@@ -898,7 +1021,8 @@ class phodevi_system extends phodevi_device_interface
 		{
 			$info = phodevi_parser::read_nvidia_extension('OpenGLVersion');
 		}
-		else if(pts_client::executable_in_path('glxinfo'))
+
+		if($info == null && pts_client::executable_in_path('glxinfo'))
 		{
 			$info = phodevi_parser::software_glxinfo_version();
 
