@@ -107,6 +107,7 @@ abstract class pts_Graph
 	// Internal Switches, Etc
 
 	protected $regression_marker_threshold = 0;
+	protected $graph_maximum_value_multiplier = 1.29;
 	protected $is_multi_way_comparison = false;
 	private $test_identifier = null;
 	protected $iveland_view = false;
@@ -183,7 +184,7 @@ abstract class pts_Graph
 
 		if($result_file != null && $result_file instanceof pts_result_file)
 		{
-			//$this->addInternalIdentifier('Identifier', null); // TODO: result file name
+			$this->addInternalIdentifier('Identifier', $result_file->get_identifier());
 			$pts_version = pts_arrays::last_element($result_file->get_system_pts_version());
 			$this->is_multi_way_comparison = $result_file->is_multi_way_comparison();
 		}
@@ -353,7 +354,7 @@ abstract class pts_Graph
 			}
 			else
 			{
-				$maximum = (floor(round($real_maximum * 1.285) / $this->graph_attr_marks) + 1) * $this->graph_attr_marks;
+				$maximum = (floor(round($real_maximum * $this->graph_maximum_value_multiplier) / $this->graph_attr_marks) + 1) * $this->graph_attr_marks;
 				$maximum = round(ceil($maximum / $this->graph_attr_marks), (0 - strlen($maximum) + 2)) * $this->graph_attr_marks;
 			}
 		}
@@ -403,7 +404,6 @@ abstract class pts_Graph
 	// Render Functions
 	//
 
-
 	public function renderGraph()
 	{
 		$this->render_graph_start();
@@ -434,7 +434,6 @@ abstract class pts_Graph
 			{
 				if($this->is_multi_way_comparison && count($this->graph_data_title) > 1)
 				{
-					// TODO: verify this is good and covered for all scenarios
 					$longest_r = pts_strings::find_longest_string($this->graph_identifiers);
 					$longest_r = explode(' - ', $longest_r);
 					$plus_extra = 0;
@@ -509,14 +508,6 @@ abstract class pts_Graph
 			}
 		}
 
-		/*
-		// Not sure this code is needed anymore...
-		if(($key_count = count($this->graph_data_title)) > 8)
-		{
-			$this->update_graph_dimensions(-1, $this->graph_attr_height + (floor(($key_count - 8) / 4) * 14), true);
-		}
-		*/
-
 		// Do the actual work
 		$this->render_graph_pre_init();
 		$this->render_graph_init();
@@ -748,7 +739,6 @@ abstract class pts_Graph
 				{
 					$this->graph_image->write_text_center($display_value, $this->graph_font, $this->graph_font_size_tick_mark, $this->graph_color_text, $px_from_left, ($top_end + 5), $px_from_left, ($top_end + 5));
 					$this->graph_image->draw_dashed_line($px_from_left + 2, $top_start, $px_from_left + 2, $top_end - 5, $this->graph_color_body, 1, 5, 5);
-
 					$this->graph_image->draw_line($px_from_left + 2, $top_end - 4, $px_from_left + 2, $top_end + 4, $this->graph_color_notches, 1);
 				}
 
@@ -814,36 +804,20 @@ abstract class pts_Graph
 			return;
 		}
 
-		$key_pos = 0;
-		$key_count = count($this->graph_data_title);
 		$component_y = $this->graph_top_start - $this->graph_key_height() - 7;
 
-		for($i = 0; $i < $key_count; $i++)
+		for($i = 0, $key_count = count($this->graph_data_title); $i < $key_count; $i++)
 		{
 			if(!empty($this->graph_data_title[$i]))
 			{
 				$this_color = $this->get_paint_color($this->graph_data_title[$i]);
-				$key_pos++;
 
-				if($i != 0 && $key_pos % $this->graph_keys_per_line == 1)
+				if($i != 0 && $i % $this->graph_keys_per_line == 0)
 				{
-					$key_pos = 1;
 					$component_y += $this->graph_key_line_height;
 				}
-				else if($this->is_multi_way_comparison)
-				{
-					$this_key_way = substr($this->graph_data_title[$i], 0, strpos($this->graph_data_title[$i], ': '));
 
-					if($i != 0 && $this_key_way != $prev_key_way)
-					{
-						$key_pos = 1;
-						$component_y += $this->graph_key_line_height;
-					}
-
-					$prev_key_way = $this_key_way;
-				}
-
-				$component_x = $this->graph_left_start + 13 + ($this->graph_key_item_width * ($key_pos - 1 % $this->graph_keys_per_line));
+				$component_x = $this->graph_left_start + 13 + ($this->graph_key_item_width * ($i % $this->graph_keys_per_line));
 
 				$this->graph_image->draw_rectangle_with_border($component_x - 13, $component_y - 5, $component_x - 3, $component_y + 5, $this_color, $this->graph_color_notches);
 				$this->graph_image->write_text_left($this->graph_data_title[$i], $this->graph_font, $this->graph_font_size_key, $this_color, $component_x, $component_y, $component_x, $component_y);
