@@ -46,6 +46,7 @@ class pts_client
 		}
 
 		self::basic_init_process(); // Initalize common / needed PTS start-up work
+		pts_network::client_startup();
 		self::core_storage_init_process();
 
 		if(!is_file(PTS_TEMP_STORAGE))
@@ -278,10 +279,16 @@ class pts_client
 				$system_log_files = array(
 					'/var/log/Xorg.0.log',
 					'/proc/cpuinfo',
+					'/proc/meminfo',
 					'/proc/modules',
 					'/proc/mounts',
 					'/proc/cmdline',
-					'/etc/X11/xorg.conf'
+					'/etc/X11/xorg.conf',
+					'/sys/kernel/debug/dri/0/radeon_pm_info',
+					'/sys/kernel/debug/dri/0/i915_capabilities',
+					'/sys/kernel/debug/dri/0/i915_cur_delayinfo',
+					'/sys/kernel/debug/dri/0/i915_drpc_info',
+					'/sys/devices/system/cpu/cpu0/cpufreq/scaling_available_frequencies',
 					);
 
 				/*
@@ -304,18 +311,26 @@ class pts_client
 				// Generate logs from system commands to backup
 				$system_log_commands = array(
 					'lspci -vvnn',
+					'lscpu',
 					'cc -v',
 					'lsusb',
 					'lsmod',
 					'sensors',
 					'dmesg',
-					'glxinfo'
+					'glxinfo',
+					'uname -a',
+					// 'udisks --dump',
+					'upower --dump'
 					);
 
 				if(phodevi::is_bsd())
 				{
 					array_push($system_log_commands, 'sysctl -a');
 				}
+				if(is_readable('/dev/mem'))
+				{
+					array_push($system_log_commands, 'dmidecode');
+				}
 
 				foreach($system_log_commands as $command_string)
 				{
@@ -324,6 +339,10 @@ class pts_client
 					if(($command_bin = pts_client::executable_in_path($command[0])))
 					{
 						$cmd_output = shell_exec('cd ' . dirname($command_bin) . ' && ./' . $command_string . ' 2>&1');
+
+						// Try to filter out any serial numbers, etc.
+						$cmd_output = pts_strings::remove_lines_containing($cmd_output, array('Serial N', 'S/N', 'Serial #', 'serial:'));
+
 						file_put_contents($system_log_dir . $command[0], $cmd_output);
 					}
 				}
@@ -379,10 +398,6 @@ class pts_client
 		{
 			pts_file_io::mkdir($dir);
 		}
-
-		phodevi::initial_setup();
-
-		//define('IS_PTS_LIVE', phodevi::read_property('system', 'username') == 'ptslive');
 	}
 	public static function init_display_mode($flags = 0)
 	{
@@ -560,11 +575,14 @@ class pts_client
 		$last_core_version = $pso->read_object('last_core_version');
 		define('FIRST_RUN_ON_PTS_UPGRADE', ($last_core_version != PTS_CORE_VERSION));
 
-		if(FIRST_RUN_ON_PTS_UPGRADE)
+		if(FIRST_RUN_ON_PTS_UPGRADE || ($pso->read_object('last_php_version') != phpversion()))
 		{
 			// Report any missing/recommended extensions
 			self::program_requirement_checks();
+		}
 
+		if(FIRST_RUN_ON_PTS_UPGRADE)
+		{
 			if($requested_gsid == false)
 			{
 				pts_openbenchmarking_client::update_gsid();
@@ -573,6 +591,7 @@ class pts_client
 			pts_client::build_temp_cache();
 		}
 		$pso->add_object('last_core_version', PTS_CORE_VERSION); // PTS version last run
+		$pso->add_object('last_php_version', phpversion()); // PHP version last run
 
 		//$last_pts_version = $pso->read_object('last_pts_version');
 		// do something here with $last_pts_version if you want that information
@@ -592,7 +611,7 @@ class pts_client
 		// Phodevi Cache Handling
 		$phodevi_cache = $pso->read_object('phodevi_smart_cache');
 
-		if($phodevi_cache instanceOf phodevi_cache && pts_flags::no_phodevi_cache() == false)
+		if($phodevi_cache instanceof phodevi_cache && pts_flags::no_phodevi_cache() == false)
 		{
 			$phodevi_cache = $phodevi_cache->restore_cache(PTS_USER_PATH, PTS_CORE_VERSION);
 			phodevi::set_device_cache($phodevi_cache);
@@ -630,6 +649,12 @@ class pts_client
 	public static function user_agreement_check($command)
 	{
 		$pso = pts_storage_object::recover_from_file(PTS_CORE_STORAGE);
+
+		if($pso == false)
+		{
+			return false;
+		}
+
 		$config_md5 = $pso->read_object('user_agreement_cs');
 		$current_md5 = md5_file(PTS_PATH . 'pts-core/user-agreement.txt');
 
@@ -1144,8 +1169,25 @@ class pts_client
 
 				if($return_value == $return_fails_on)
 				{
-					pts_client::$display->generic_error('Argument Missing.');
-					echo 'CORRECT SYNTAX' . PHP_EOL . 'phoronix-test-suite ' . str_replace('_', '-', $command) . ' ' . implode(' ', $argument_checks) . PHP_EOL . PHP_EOL;
+					$command_alias = defined($command . '::doc_use_alias') ? constant($command . '::doc_use_alias') : $command;
+
+					if((isset($pass_args[$argument_check->get_argument_index()]) && !empty($pass_args[$argument_check->get_argument_index()])) || ($argument_check->get_argument_index() == 'VARIABLE_LENGTH' && !empty($pass_args)))
+					{
+						pts_client::$display->generic_error('Invalid Argument: ' . implode(' ', $pass_args));
+					}
+					else
+					{
+						pts_client::$display->generic_error('Argument Missing.');
+					}
+
+					echo 'CORRECT SYNTAX' . PHP_EOL . 'phoronix-test-suite ' . str_replace('_', '-', $command_alias) . ' ' . implode(' ', $argument_checks) . PHP_EOL . PHP_EOL;
+
+					if(method_exists($command, 'invalid_command'))
+					{
+						call_user_func_array(array($command, 'invalid_command'), $pass_args);
+						echo PHP_EOL;
+					}
+
 					return false;
 				}
 				else
@@ -1178,6 +1220,7 @@ class pts_client
 			pts_module_manager::run_command($module, $module_command, $pass_args);
 			pts_module_manager::set_current_module(null);
 		}
+		echo PHP_EOL;
 
 		pts_module_manager::module_process('__post_option_process', $command);
 	}
@@ -1496,7 +1539,7 @@ class pts_client
 
 			if($browser != null)
 			{
-				shell_exec($browser . ' "' . $URL . '" &');
+				shell_exec($browser . ' "' . $URL . '" 2> /dev/null &');
 			}
 			else
 			{
@@ -1535,6 +1578,91 @@ class pts_client
 
 		return $results;
 	}
+	public static function code_error_handler($error_code, $error_string, $error_file, $error_line)
+	{
+		if(($error_code & (E_USER_ERROR | E_USER_WARNING | E_USER_NOTICE)))
+		{
+			// It's a self-generated error by pts-core code intentionally
+			return self::user_error_handler($error_code, $error_string, $error_file, $error_line);
+		}
+
+		/*if(!(error_reporting() & $error_code))
+		{
+			return;
+		}*/
+
+		switch($error_code)
+		{
+			case E_ERROR:
+			case E_PARSE:
+				$error_type = 'ERROR';
+				break;
+			case E_WARNING:
+			case E_NOTICE:
+				if(($s = strpos($error_string, 'Undefined ')) !== false && ($x = strpos($error_string, ': ', $s)) !== false)
+				{
+					$error_string = 'Undefined: ' . substr($error_string, ($x + 2));
+				}
+				else if(strpos($error_string, 'Name or service not known') !== false || strpos($error_string, 'HTTP request failed') !== false || strpos($error_string, 'fopen') !== false || strpos($error_string, 'file_get_contents') !== false)
+				{
+					// Don't report network errors
+					return;
+				}
+				$error_type = 'NOTICE';
+				break;
+			default:
+				$error_type = $error_code;
+				break;
+		}
+
+		echo PHP_EOL . '[' . $error_type . '] ' . $error_string . ' in ' . basename($error_file) . ':' . $error_line . PHP_EOL;
+
+		if($error_type == 'ERROR')
+		{
+			exit(1);
+		}
+	}
+	public static function user_error_handler($error_code, $error_string, $error_file, $error_line)
+	{
+/*
+
+		trigger_error('Scheisse', E_USER_WARNING);
+		trigger_error('Okay', E_USER_NOTICE);
+		trigger_error('F', E_USER_ERROR);
+*/
+		switch($error_code)
+		{
+			case E_USER_ERROR:
+				$error_type = 'ERROR';
+				break;
+			case E_USER_NOTICE:
+				if(pts_client::is_client_debug_mode() == false)
+				{
+					return;
+				}
+				$error_type = 'NOTICE';
+				break;
+			case E_USER_WARNING:
+				$error_type = 'NOTICE'; // Yes, report warnings as a notice label
+				break;
+		}
+
+		echo PHP_EOL . '[' . $error_type . '] ' . $error_string . (pts_client::is_client_debug_mode() ? ' in ' . basename($error_file) . ':' . $error_line : null) . PHP_EOL;
+		return;
+	}
+	public static function is_client_debug_mode()
+	{
+		return false; // TODO
+	}
+}
+
+// Some extra magic
+set_error_handler(array('pts_client', 'code_error_handler'));
+
+if(PTS_IS_CLIENT && (PTS_IS_DEV_BUILD || pts_client::is_client_debug_mode()))
+{
+	// Enable more verbose error reporting only when PTS is in development with milestone (alpha/beta) releases but no release candidate (r) or gold versions
+	error_reporting(E_ALL | E_NOTICE | E_STRICT);
 }
 
 ?>
