@@ -30,7 +30,7 @@ class pts_network
 		}
 
 		$stream_context = pts_network::stream_context_create(null, $override_proxy, $override_proxy_port);
-		$contents = @pts_file_io::file_get_contents($url, 0, $stream_context);
+		$contents = pts_file_io::file_get_contents($url, 0, $stream_context);
 
 		return $contents;
 	}
@@ -44,8 +44,8 @@ class pts_network
 		$upload_data = http_build_query($to_post_data);
 		$http_parameters = array('http' => array('method' => 'POST', 'content' => $upload_data));
 		$stream_context = pts_network::stream_context_create($http_parameters);
-		$opened_url = @fopen($url, 'rb', false, $stream_context);
-		$response = @stream_get_contents($opened_url);
+		$opened_url = fopen($url, 'rb', false, $stream_context);
+		$response = stream_get_contents($opened_url);
 
 		return $response;
 	}
@@ -255,15 +255,24 @@ class pts_network
 			define('NO_NETWORK_COMMUNICATION', true);
 			//echo PHP_EOL . 'Network Communication Is Disabled For Your User Configuration.' . PHP_EOL . PHP_EOL;
 		}
-		/* else
+		else
 		{
 			$server_response = pts_network::http_get_contents('http://www.phoronix-test-suite.com/PTS', false, false);
 
 			if($server_response != 'PTS')
 			{
-				define('NO_NETWORK_COMMUNICATION', true);
+				// Failed to connect to PTS server
+
+				// As a last resort, see if it can resolve IP to Google.com as a test for Internet connectivity...
+				// i.e. in case Phoronix server is down or some other issue, so just see if Google will resolve
+				// If google.com fails to resolve, it will simply return the original string
+				if(gethostbyname('google.com') == 'google.com')
+				{
+					define('NO_NETWORK_COMMUNICATION', true);
+					echo PHP_EOL . 'NOTICE: No Network Connectivity' . PHP_EOL . PHP_EOL;
+				}
 			}
-		}*/
+		}
 
 		if(!defined('NO_NETWORK_COMMUNICATION') && ini_get('file_uploads') == 'Off')
 		{
