@@ -21,17 +21,11 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-define('PTS_VERSION', '3.4.0');
-define('PTS_CORE_VERSION', 3400);
-define('PTS_CODENAME', 'LILLESAND');
+define('PTS_VERSION', '3.6.0');
+define('PTS_CORE_VERSION', 3600);
+define('PTS_CODENAME', 'ARENDAL');
 define('PTS_IS_CLIENT', (defined('PTS_MODE') && PTS_MODE == 'CLIENT'));
-
-
-if(PTS_IS_CLIENT && substr(PTS_VERSION, -2, 1) == 'm')
-{
-	// Enable more verbose error reporting only when PTS is in development with milestone (alpha/beta) releases but no release candidate (r) or gold versions
-	error_reporting(E_ALL | E_NOTICE | E_STRICT);
-}
+define('PTS_IS_DEV_BUILD', (substr(PTS_VERSION, -2, 1) == 'm'));
 
 function pts_codename($full_string = false)
 {
